@@ -246,7 +246,6 @@ SMB_Tree_Handle SMB_Logon_And_TCon(SMB_Handle_Type Con_Handle,
     AndXCom = SMB_Hdr(pkt) + SMB_ssetpNTLM_len + param_len - SMB_hdr_wct_offset;
 
   }
-
     *(AndXCom + SMB_hdr_wct_offset) = 4;
     *(AndXCom + SMB_tconx_axc_offset) = 0xFF;  /* No command */
     SSVAL(AndXCom, SMB_tconx_axo_offset, 0);
@@ -357,6 +356,7 @@ int SMB_Logon_TCon_Open(SMB_Handle_Type Con_Handle, char *UserName,
 			char *PassWord,
 			char *service,
 			char *service_type,
+			SMB_Tree_Handle *Tree_Handle,
 			char *filename,
 			WORD mode,
 			WORD search,
@@ -364,7 +364,7 @@ int SMB_Logon_TCon_Open(SMB_Handle_Type Con_Handle, char *UserName,
 
 { struct RFCNB_Pkt *pkt;
   int param_len, i, pkt_len, tcon_len, tcon_param_len, open_len, 
-      open_param_len;
+      open_param_len, header_len;
   struct SMB_File_Def *file_tmp;
   SMB_Tree_Handle tree;
   char *p, *AndXCom;
@@ -419,13 +419,26 @@ int SMB_Logon_TCon_Open(SMB_Handle_Type Con_Handle, char *UserName,
 
   /* Now build the correct structure */
 
+  /* We send a null password in the TconAndX ... */
+
+  tcon_len = SMB_tconx_len - SMB_hdr_wct_offset;
+  tcon_param_len = strlen(service) + 1 + strlen(service_type) + 1;
+
+  open_len = SMB_openx_len - SMB_hdr_wct_offset;
+  open_param_len = 1 + strlen(filename) + 1;  /* AsciiID + null */
+
   if (Con_Handle -> protocol < SMB_P_NT1) {
 
-    param_len = strlen(UserName) + 1 + strlen(PassWord) + 
+    /* We don't do encrypted passwords yet */
+
+    param_len = strlen(UserName) + 1 + strlen(PassWord) + 1 +
                 strlen(Con_Handle -> PDomain) + 1 + 
 	        strlen(Con_Handle -> OSName) + 1;
 
-    pkt_len = SMB_ssetpLM_len + param_len;
+    header_len = SMB_ssetpLM_len + param_len;
+
+    pkt_len = header_len + tcon_len + tcon_param_len + 
+              open_len + open_param_len;
 
     pkt = (struct RFCNB_Pkt *)RFCNB_Alloc_Pkt(pkt_len);
 
@@ -444,16 +457,16 @@ int SMB_Logon_TCon_Open(SMB_Handle_Type Con_Handle, char *UserName,
     SSVAL(SMB_Hdr(pkt), SMB_hdr_pid_offset, Con_Handle -> pid);
     SSVAL(SMB_Hdr(pkt), SMB_hdr_tid_offset, 0);
     SSVAL(SMB_Hdr(pkt), SMB_hdr_mid_offset, Con_Handle -> mid);
-    SSVAL(SMB_Hdr(pkt), SMB_hdr_uid_offset, Con_Handle -> uid);
+    SSVAL(SMB_Hdr(pkt), SMB_hdr_uid_offset, 0);
     *(SMB_Hdr(pkt) + SMB_hdr_wct_offset) = 10;
-    *(SMB_Hdr(pkt) + SMB_hdr_axc_offset) = 0xFF;    /* No extra command */
-    SSVAL(SMB_Hdr(pkt), SMB_hdr_axo_offset, 0);
+    *(SMB_Hdr(pkt) + SMB_hdr_axc_offset) = SMBtconX;  
+    SSVAL(SMB_Hdr(pkt), SMB_hdr_axo_offset, SMB_ssetpLM_len + param_len);
 
     SSVAL(SMB_Hdr(pkt), SMB_ssetpLM_mbs_offset, SMBLIB_MAX_XMIT);
     SSVAL(SMB_Hdr(pkt), SMB_ssetpLM_mmc_offset, 2);
     SSVAL(SMB_Hdr(pkt), SMB_ssetpLM_vcn_offset, Con_Handle -> pid);
     SIVAL(SMB_Hdr(pkt), SMB_ssetpLM_snk_offset, 0);
-    SSVAL(SMB_Hdr(pkt), SMB_ssetpLM_pwl_offset, strlen(PassWord));
+    SSVAL(SMB_Hdr(pkt), SMB_ssetpLM_pwl_offset, strlen(PassWord) + 1);
     SIVAL(SMB_Hdr(pkt), SMB_ssetpLM_res_offset, 0);
     SSVAL(SMB_Hdr(pkt), SMB_ssetpLM_bcc_offset, param_len);
 
@@ -465,7 +478,7 @@ int SMB_Logon_TCon_Open(SMB_Handle_Type Con_Handle, char *UserName,
 
     strcpy(p, PassWord);
 
-    p = p + strlen(PassWord);
+    p = p + strlen(PassWord) + 1;
 
     strcpy(p, UserName);
     p = p + strlen(UserName);
@@ -482,6 +495,8 @@ int SMB_Logon_TCon_Open(SMB_Handle_Type Con_Handle, char *UserName,
     p = p + strlen(Con_Handle -> OSName);
     *p = 0;
 
+    AndXCom = SMB_Hdr(pkt) + SMB_ssetpLM_len + param_len - SMB_hdr_wct_offset;
+
   }
   else {
 
@@ -492,15 +507,9 @@ int SMB_Logon_TCon_Open(SMB_Handle_Type Con_Handle, char *UserName,
 	        strlen(Con_Handle -> OSName) + 1 + 
 		strlen(Con_Handle -> LMType) + 1;
 
-    tcon_len = SMB_tconx_len - SMB_hdr_wct_offset;
-    open_len = SMB_openx_len - SMB_hdr_wct_offset;
+    header_len = SMB_ssetpNTLM_len + param_len;
 
-    /* We send a null password as we sent one in the setup and X */
-
-    tcon_param_len = 1 + strlen(service) + 1 + strlen(service_type) + 1;
-    open_param_len = 1 + strlen(filename) + 1;  /* AsciiID + null */
-
-    pkt_len = SMB_ssetpNTLM_len + param_len + tcon_len + tcon_param_len +
+    pkt_len = header_len + tcon_len + tcon_param_len +
               open_len + open_param_len;
 
     pkt = (struct RFCNB_Pkt *)RFCNB_Alloc_Pkt(pkt_len);
@@ -520,7 +529,7 @@ int SMB_Logon_TCon_Open(SMB_Handle_Type Con_Handle, char *UserName,
     SSVAL(SMB_Hdr(pkt), SMB_hdr_pid_offset, Con_Handle -> pid);
     SSVAL(SMB_Hdr(pkt), SMB_hdr_tid_offset, 0);
     SSVAL(SMB_Hdr(pkt), SMB_hdr_mid_offset, Con_Handle -> mid);
-    SSVAL(SMB_Hdr(pkt), SMB_hdr_uid_offset, Con_Handle -> uid);
+    SSVAL(SMB_Hdr(pkt), SMB_hdr_uid_offset, 0);
     *(SMB_Hdr(pkt) + SMB_hdr_wct_offset) = 13;
     *(SMB_Hdr(pkt) + SMB_hdr_axc_offset) = SMBtconX;
     SSVAL(SMB_Hdr(pkt), SMB_hdr_axo_offset, SMB_ssetpNTLM_len + param_len);
@@ -570,46 +579,46 @@ int SMB_Logon_TCon_Open(SMB_Handle_Type Con_Handle, char *UserName,
 
     AndXCom = SMB_Hdr(pkt) + SMB_ssetpNTLM_len + param_len - SMB_hdr_wct_offset;
 
-    *(AndXCom + SMB_hdr_wct_offset) = 4;
-    *(AndXCom + SMB_tconx_axc_offset) = SMBopenX;
-    SSVAL(AndXCom, SMB_tconx_axo_offset, (SMB_ssetpNTLM_len + param_len + 
-					  tcon_len + tcon_param_len));
-    SSVAL(AndXCom, SMB_tconx_flg_offset, 0);   /* Don't disconnect TID    */
-    SSVAL(AndXCom, SMB_tconx_pwl_offset, 1);   /* No password, but a null */
-    SSVAL(AndXCom, SMB_tconx_bcc_offset, tcon_param_len);
-
-    p = (char *)(AndXCom + SMB_tconx_buf_offset);
-
-    *p = 0; 
-    p = p + 1;
-    strcpy(p, service);
-    p = p + strlen(service) + 1;
-    strcpy(p, service_type);
-
-    /* Now the open bit ... */
-
-    AndXCom = AndXCom + tcon_len + tcon_param_len;  /* Should get us there */
-
-    *(AndXCom + SMB_hdr_wct_offset) = 15;
-    *(AndXCom + SMB_openx_axc_offset) = 0xFF;
-    *(AndXCom + SMB_openx_axr_offset) = 0;
-    SSVAL(AndXCom, SMB_openx_axo_offset, 0);
-    SSVAL(AndXCom, SMB_openx_flg_offset, 0);
-    SSVAL(AndXCom, SMB_openx_mod_offset, mode);
-    SSVAL(AndXCom, SMB_openx_atr_offset, search);
-    SSVAL(AndXCom, SMB_openx_fat_offset, 0);
-    SIVAL(AndXCom, SMB_openx_tim_offset, 0);
-    SSVAL(AndXCom, SMB_openx_ofn_offset, 0x0011); /* Create or open */
-    SIVAL(AndXCom, SMB_openx_als_offset, 0);
-    SSVAL(AndXCom, SMB_openx_bcc_offset, open_param_len);
-
-    p = (char *)(AndXCom + SMB_openx_buf_offset);
-
-    /* *p = SMBasciiID; */
-    strcpy(p, filename);
-
   }
 
+  *(AndXCom + SMB_hdr_wct_offset) = 4;
+  *(AndXCom + SMB_tconx_axc_offset) = SMBopenX;
+  SSVAL(AndXCom, SMB_tconx_axo_offset, (header_len + 
+					tcon_len + tcon_param_len));
+  SSVAL(AndXCom, SMB_tconx_flg_offset, 0);   /* Don't disconnect TID    */
+  SSVAL(AndXCom, SMB_tconx_pwl_offset, 0);   /* No password */
+  SSVAL(AndXCom, SMB_tconx_bcc_offset, tcon_param_len);
+
+  p = (char *)(AndXCom + SMB_tconx_buf_offset);
+
+/*  *p = 0; 
+  p = p + 1; */
+  strcpy(p, service);
+  p = p + strlen(service) + 1;
+  strcpy(p, service_type);
+
+  /* Now the open bit ... */
+
+  AndXCom = AndXCom + tcon_len + tcon_param_len;  /* Should get us there */
+
+  *(AndXCom + SMB_hdr_wct_offset) = 15;
+  *(AndXCom + SMB_openx_axc_offset) = 0xFF;
+  *(AndXCom + SMB_openx_axr_offset) = 0;
+  SSVAL(AndXCom, SMB_openx_axo_offset, 0);
+  SSVAL(AndXCom, SMB_openx_flg_offset, 0);
+  SSVAL(AndXCom, SMB_openx_mod_offset, mode);
+  SSVAL(AndXCom, SMB_openx_atr_offset, search);
+  SSVAL(AndXCom, SMB_openx_fat_offset, 0);
+  SIVAL(AndXCom, SMB_openx_tim_offset, 0);
+  SSVAL(AndXCom, SMB_openx_ofn_offset, 0x0011); /* Create or open */
+  SIVAL(AndXCom, SMB_openx_als_offset, 0);
+  SSVAL(AndXCom, SMB_openx_bcc_offset, open_param_len);
+
+  p = (char *)(AndXCom + SMB_openx_buf_offset);
+
+  /* *p = SMBasciiID; */
+  strcpy(p, filename);
+
   /* Now send it and get a response */
 
   if (RFCNB_Send(Con_Handle -> Trans_Connect, pkt, pkt_len) < 0){
@@ -731,6 +740,8 @@ int SMB_Logon_TCon_Open(SMB_Handle_Type Con_Handle, char *UserName,
 
   RFCNB_Free_Pkt(pkt);
 
+  *Tree_Handle = tree;
+
   return(0);
 
 }
