@@ -519,7 +519,7 @@ static int SMB_Types[] = {SMB_P_Core,
 		          SMB_P_NT1,
 		          SMB_P_NT1,
 		          SMB_P_NT1,
-		          NULL};
+		          -1};
 
 typedef struct SMB_Status {
 
