@@ -13,7 +13,7 @@ void usage()
 
 {
 
-  fprintf(stderr, "test_smblib [-s <file-service>] [-w <write-size] server\n");
+  fprintf(stderr, "test_smblib [-s <file-service>] [-w <write-size] [-u <user>] server\n");
 
 }
 
@@ -26,9 +26,7 @@ char *SMB_Prots[] = {"PC NETWORK PROGRAM 1.0",
 			    "LM1.2X002",
 			    "DOS LANMAN2.1",
 			    "LANMAN2.1",
-			    "Samba",
 			    "NT LM 0.12",
-			    "NT LANMAN 1.0",
 			    NULL};
 
 main(int argc, char *argv[])
@@ -109,7 +107,7 @@ main(int argc, char *argv[])
 
   sprintf(service_name, "%c%c%s%c%s", slosh, slosh, server, slosh, service);
 
-  strcpy(file_name, "netfax.q");
+  strcpy(file_name, "\\netfax.q");
 
   fprintf(stderr, "Connecting to %s ...\n", service_name);
 
@@ -176,7 +174,7 @@ main(int argc, char *argv[])
 
     /* Should check the protocol level ... */
 
-    if (SMB_Logon_TCon_Open(con, username, password, service, "A:",
+    if (SMB_Logon_TCon_Open(con, username, password, service_name, "A:", &tree,
 			    file_name, SMB_AMODE_OPENRW, SMB_FA_ORD, &file) < 0) {
 
       fprintf(stderr, "Unable to logon and tree connect to server %s ...\n",
@@ -343,7 +341,7 @@ main(int argc, char *argv[])
 
   fprintf(stderr, "Attempting to create file 'xyzwertyaaa.dfgty' ...\n");
 
-  file = SMB_Create(con, NULL, "xyzwertyaaa.dfgty", SMB_FA_ORD);
+  file = SMB_Create(tree, NULL, "xyzwertyaaa.dfgty", SMB_FA_ORD);
 
   if (file != NULL) { /* Do something with the file ... */
 
@@ -384,7 +382,7 @@ main(int argc, char *argv[])
 
   fprintf(stderr, "Attempting to delete the file 'delete.txt' ...\n");
 
-  if (SMB_Delete(con, "delete.txt", SMB_FA_ORD) < 0) {
+  if (SMB_Delete(tree, "delete.txt", SMB_FA_ORD) < 0) {
 
     fprintf(stderr, "The file could not be deleted ... \n");
 
@@ -406,7 +404,7 @@ main(int argc, char *argv[])
     fprintf(stderr, "Perhaps we are talking to PW4Ultrix ..., try again ...\n");
     fprintf(stderr, "Trying to delete \\DELETE.TXT ... \n");
 
-    if (SMB_Delete(con, "\\DELETE.TXT", SMB_FA_ORD) < 0) {
+    if (SMB_Delete(tree, "\\DELETE.TXT", SMB_FA_ORD) < 0) {
       fprintf(stderr, "Still could not be deleted ...\n");
   
       if (SMB_Get_Last_Error() == SMBlibE_Remote) {
@@ -439,7 +437,7 @@ main(int argc, char *argv[])
 
   fprintf(stderr, "Attempting to open '%s' ...\n", file_name);
 
-  file = SMB_Create(con, NULL, file_name, 0);
+  file = SMB_Create(tree, NULL, file_name, 0);
 
   if (file == NULL) { /* It failed ... why? */
 
@@ -465,7 +463,7 @@ main(int argc, char *argv[])
 
   fprintf(stderr, "Attempting to create directory \'%s\' ...\n", file_name);
 
-  if (SMB_Create_Dir(con, file_name) < 0) {
+  if (SMB_Create_Dir(tree, file_name) < 0) {
 
     fprintf(stderr, "Creating directory \'%s\' failed ...\n", file_name);
 
@@ -473,7 +471,7 @@ main(int argc, char *argv[])
 
   fprintf(stderr, "Attempting to check the directory \'%s\' ...\n", file_name);
 
-  if (SMB_Check_Dir(con, file_name) < 0) {
+  if (SMB_Check_Dir(tree, file_name) < 0) {
 
     if (SMB_Get_Last_Error() == SMBlibE_Remote) {
 
@@ -495,7 +493,7 @@ main(int argc, char *argv[])
 
   fprintf(stderr, "Attempting to delete directory \'%s\' ... \n", file_name);
 
-  if (SMB_Delete_Dir(con, file_name) < 0) {
+  if (SMB_Delete_Dir(tree, file_name) < 0) {
 
     fprintf(stderr, "Deleting directory \'%s\' failed ...\n", file_name);
 
