@@ -44,18 +44,42 @@ void rfcnb_alarm(int sig)
 
 int RFCNB_Set_Timeout(int seconds)
 
-{ struct sigvec invec, outvec; 
+{
+  /* If we are on a Bezerkeley system, use sigvec, else sigaction */
+#ifndef SA_RESTART
+  struct sigvec invec, outvec; 
+#else
+  struct sigaction inact, outact;
+#endif
 
   RFCNB_Timeout = seconds;
 
   if (RFCNB_Timeout > 0) { /* Set up handler to ignore but not restart */
 
+#ifndef SA_RESTART
     invec.sv_handler = (void (*)())rfcnb_alarm;
     invec.sv_mask = 0;
     invec.sv_flags = SV_INTERRUPT;
 
     if (sigvec(SIGALRM, &invec, &outvec)  < 0)
       return(-1);
+#else
+    inact.sa_handler = (void (*)())rfcnb_alarm;
+#ifdef Solaris
+    /* Solaris seems to have an array of vectors ... */
+    inact.sa_mask.__sigbits[0] = 0;
+    inact.sa_mask.__sigbits[1] = 0;
+    inact.sa_mask.__sigbits[2] = 0;
+    inact.sa_mask.__sigbits[3] = 0;
+#else
+    inact.sa_mask = 0;
+#endif
+    inact.sa_flags = 0;    /* Don't restart */
+
+    if (sigaction(SIGALRM, &inact, &outact) < 0)
+      return(-1);
+
+#endif
 
   }
 
@@ -296,6 +320,10 @@ int RFCNB_Get_Pkt(struct RFCNB_Con *con, struct RFCNB_Pkt *pkt, int len)
 
   pkt_len = RFCNB_Pkt_Len(hdr);
 
+#ifdef RFCNB_DEBUG
+  fprintf(stderr, "Reading Pkt: Length = %i\n", pkt_len);
+#endif  
+
   /* Now copy in the hdr */
 
   memcpy(pkt -> data, hdr, sizeof(hdr));
